;;;============================================================================

;;; File: "main.scm"

;;; Copyright (c) 2012 by Marc Feeley, All Rights Reserved.

;;;============================================================================

;(namespace ("app#") ("" include))

(include "~~lib/gambit#.scm")

(namespace
 ("intf#"
  set-navigation-bar
  set-navigation
  set-event-handler
  has-prefix?
  get-event-parameters
  set-view-content
  show-view
  eval-js-in-webView
  set-webView-content-from-file
  set-toolbar-alpha
)
 (""
  app
  repl
  repl-eval)
 ("gr#"
  wiki-event-handler
  handle-app-become-active-event
  handle-create-account-event
  handle-navigation-event
  generic-event-handler)
)

;(namespace ("app#" pp))

;;;============================================================================

(define debug-ui? #t)

;; Intercept events.

(define set-event-handler
  (let ((old-set-event-handler set-event-handler))
    (lambda (proc)
      (old-set-event-handler
       (lambda (old-event-handler)
         (let ((eh (proc old-event-handler)))
           (lambda (event)
             (or (and (equal? event "NAV0")
                      (begin
                        (repl)
                        #t))
                 (and (equal? event "NAV1")
                      (begin
                        (app)
                        #t))
                 (eh event)))))))))

(define pp ;; redefine pp so that output goes to REPL view
  (lambda args
    (for-each
     (lambda (arg)
       (pretty-print arg (##vector-ref (##thread-repl-channel-get! #1) 4)))
     args)
    (repl)))

;;;----------------------------------------------------------------------------

(define (app-start)
  (app-navigation-bar)
  (app-init)
  (app))

(define (app-navigation-bar)
  (if debug-ui?
      (let* ((this-dir
              (path-directory (this-source-file)))
             (name
              (path-strip-directory
               (path-strip-trailing-directory-separator this-dir))))
        (set-navigation-bar (list "Gambit REPL" name)))
      (begin
        ;;(set-toolbar-alpha 0.0) ;; hide toolbar
        '(set-navigation-bar '()))))

(define (app-init)
  (set-webView-content-from-file
   1
   (path-expand "index.html" (path-directory (this-source-file)))
   (path-directory (this-source-file))))

(define (app)
  (set-event-handler (lambda (old-event-handler) app-event-handler))
  (set-navigation 1)
  (show-view 1))

;;;----------------------------------------------------------------------------

(define (app-event-handler event)
  (cond ((has-prefix? event "event:add:") =>
         (lambda (rest)
           (let ((params (get-event-parameters rest)))
             ;;(pp params)
             (add (string->number (list-ref params 0)))
             )))

        (else
         (generic-event-handler event))))

(define (add n)
  (let* ((count
          (eval-js-in-webView 1 "document.getElementById('count').innerHTML"))
         (count+n
          (number->string (+ (string->number count) n))))
    (eval-js-in-webView 1 (string-append "document.getElementById('count').innerHTML = '" count+n "';"))))

;;;----------------------------------------------------------------------------

(app-start)

;;;============================================================================
